@@ -1,12 +1,14 @@
-#! perl
+#! perl --			-*- coding: utf-8 -*-
+
+use utf8;
 
 # Einde.pm -- Eindejaarsverwerking
-# RCS Info        : $Id: Einde.pm,v 1.16 2008/02/07 12:30:04 jv Exp $
+# RCS Info        : $Id: Einde.pm,v 1.22 2009/11/04 22:24:03 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Sun Oct 16 21:27:40 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Feb  7 13:30:02 2008
-# Update Count    : 224
+# Last Modified On: Wed Nov  4 23:21:55 2009
+# Update Count    : 246
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -19,7 +21,7 @@ package EB::Tools::Einde;
 use strict;
 use warnings;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.16 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.22 $ =~ /(\d+)/g;
 
 use EB;
 use EB::Format;
@@ -34,8 +36,6 @@ sub new {
     return bless {} => $class;
 }
 
-sub min($$) { $_[0] lt $_[1] ? $_[0] : $_[1] }
-
 sub perform {
     my ($self, $args, $opts) = @_;
 
@@ -54,7 +54,11 @@ sub perform {
     my $def = $opts->{definitief};
     my $eb;
     if ( $opts->{eb} ) {
-	open($eb, '>', $opts->{eb});
+	unless ( open($eb, '>:encoding(utf-8)', $opts->{eb}) ) {
+	    warn("?", __x("Fout tijdens het aanmaken van bestand {file}: {err}",
+			 file => $opts->{eb}, err => $!."")."\n");
+	    return;
+	}
 	$opts->{eb_handle} = $eb;
     }
 
@@ -170,12 +174,15 @@ sub perform {
 
       ## Afboeken BTW
 
-      for ( qw(ih il vh vl) ) {
+      foreach ( @{ $dbh->std_accs } ) {
+	my $stdacc = $_;	# copy for mod
+	next unless $stdacc =~ /^btw_[iv].$/;
+	next unless defined( $stdacc = $dbh->std_acc($stdacc, undef) );
 	($acc_id, $acc_desc, $acc_balance) =
 	  @{$dbh->do("SELECT acc_id,acc_desc,acc_balance".
 		     " FROM ${tbl}".
 		     " WHERE acc_id = ?",
-		     $dbh->std_acc("btw_$_"))};
+		     $stdacc)};
 	next unless $acc_balance;
 	$tot += $acc_balance;
 	$dbh->sql_insert("Boekjaarbalans",
